@@ -31,4 +31,9 @@ STATIC_URL = setting_overrides.get(
 DEBUG = setting_overrides.get(
     'DEBUG',
     settings.DEBUG,
+)
+
+CACHE = setting_overrides.get(
+    'CACHE',
+    not settings.DEBUG,
 )
\ No newline at end of file
